@@ -1,5 +1,5 @@
 /*
- *  $Id: io.c,v 1.2 1999/08/16 00:25:10 trockij Exp $
+ *  $Id: io.c,v 1.2.2.1 1999/09/14 17:39:20 trockij Exp $
  */
 
 /*
@@ -46,15 +46,18 @@ setup_connect (muxconn_t *muxlist, char *muxerr, int muxerrsiz)
     c = muxlist;
     err = 0;
 
-    if ((pe = getprotobyname ("tcp")) == NULL) {
+    if ((pe = getprotobyname ("tcp")) == NULL)
+    {
 	snprintf (muxerr, muxerrsiz, "could not look up tcp proto");
 	return 0;
     }
 
-    while (c != NULL) {
-
+    while (c != NULL)
+    {
 	s = socket (AF_INET, SOCK_STREAM, pe->p_proto);
-	if (s < 0) {
+
+	if (s < 0)
+	{
 	    snprintf (muxerr, muxerrsiz, "could not create socket: %s",
 		    sys_errlist[errno]);
 	    return 0;
@@ -64,7 +67,8 @@ setup_connect (muxconn_t *muxlist, char *muxerr, int muxerrsiz)
 	 * set nonblocking
 	 */
 	c->fd = s;
-	if ( (fl = fcntl (s, F_GETFL, 0)) < 0) {
+	if ( (fl = fcntl (s, F_GETFL, 0)) < 0)
+	{
 	    snprintf (muxerr, muxerrsiz, "could not get flags: %s",
 		    sys_errlist[errno]);
 	    return 0;
@@ -72,7 +76,8 @@ setup_connect (muxconn_t *muxlist, char *muxerr, int muxerrsiz)
 
 	fl |= O_NONBLOCK;
 	
-	if ( (fl = fcntl (s, F_SETFL, fl)) < 0) {
+	if ( (fl = fcntl (s, F_SETFL, fl)) < 0)
+	{
 	    snprintf (muxerr, muxerrsiz, "could not set flags: %s",
 		    sys_errlist[errno]);
 	    return 0;
@@ -83,13 +88,17 @@ setup_connect (muxconn_t *muxlist, char *muxerr, int muxerrsiz)
 	 */
 	c->saddr.sin_port = htons (c->port);
 	
-	if (connect (s, &c->saddr, sizeof (c->saddr)) < 0 && errno != EINPROGRESS) {
+	if (connect (s, &c->saddr, sizeof (c->saddr)) == -1 && errno != EINPROGRESS)
+	{
 	    c->status = MUXCONN_FAILURE;
 	    snprintf (c->detail, sizeof (c->detail),
 		    "could not connect: %s", sys_errlist[errno]);
 	    snprintf (c->summ, sizeof (c->summ),
 		    "%s", c->hostname);
-	} else {
+
+	}
+	else
+	{
 	    c->status = MUXCONN_INPROGRESS;
 	}
 
@@ -118,8 +127,10 @@ io_loop (muxconn_t *muxlist, int timeout,
     
     d = 0;
     c = muxlist;
-    while (c->next != NULL) {
-	if (c->status != MUXCONN_INPROGRESS) {
+    while (c->next != NULL)
+    {
+	if (c->status != MUXCONN_INPROGRESS)
+	{
 	    c = c->next;
 	    continue;
 	}
@@ -133,16 +144,21 @@ io_loop (muxconn_t *muxlist, int timeout,
     timerclear (&t0);
     timerclear (&t1);
 
-    if (gettimeofday (&t0, NULL) < 0) {
+    if (gettimeofday (&t0, NULL) == -1)
+    {
 	snprintf (err, errsiz, "could not gettimeofday: %s",
 		sys_errlist[errno]);
 	return 0;
     }
     
-    while (timerisset (&tval)) {
+    while (timerisset (&tval))
+    {
+#if 0
 	select ();
+#endif
 
-	if (gettimeofday (&t1, NULL) < 0) {
+	if (gettimeofday (&t1, NULL) < 0)
+	{
 	    snprintf (err, errsiz, "could not gettimeofday: %s",
 		    sys_errlist[errno]);
 	    return 0;
@@ -150,7 +166,8 @@ io_loop (muxconn_t *muxlist, int timeout,
     }
     
     c = muxlist;
-    while (c->next != NULL) {
+    while (c->next != NULL)
+    {
 	if (c->status == MUXCONN_INPROGRESS)
 	    c->status = MUXCONN_TIMEOUT;
 	c = c->next;
