@@ -1,5 +1,5 @@
 /*
- * $Id: setup.c,v 1.2 1999/08/16 00:25:10 trockij Exp $
+ * $Id: setup.c,v 1.2.2.1 1999/09/14 17:39:22 trockij Exp $
  */
 
 /*
@@ -55,21 +55,26 @@ read_expect (char *file)
     cur->next = (chat_sess_t *) NULL;
     lnum = 0;
 
-    while (fgets (buf, BUFSIZ, f) != NULL) {
+    while (fgets (buf, BUFSIZ, f) != NULL)
+    {
 	lnum++;
 	if (strchr (buf, '#') == buf)
 	    continue;
 	
 	buf[strlen (buf) -1] = '\0';
-	if (send_expect) {
+	if (send_expect)
+	{
 	    strncpy (cur->expect, buf, BUFSIZ);
 	    send_expect--;
-	} else {
+	}
+	else
+	{
 	    strncpy (cur->send, buf, BUFSIZ);
 	    send_expect++;
 
 	    ncur = (chat_sess_t *) calloc (1, sizeof (chat_sess_t));
-	    if (ncur == NULL) {
+	    if (ncur == NULL)
+	    {
 		fclose (f);
 		return ((chat_sess_t *) NULL);
 	    }
@@ -81,7 +86,8 @@ read_expect (char *file)
     
     cur->next = (chat_sess_t *) NULL;
     
-    if (ferror (f)) {
+    if (ferror (f))
+    {
 	fclose (f);
 	return ((chat_sess_t *)NULL);
     }
@@ -101,7 +107,8 @@ dump_chat_sess (chat_sess_t *c)
     chat_sess_t *p;
     
     p = c;
-    while (p->next != NULL) {
+    while (p->next != NULL)
+    {
 	printf ("exp: %s\n", p->expect);
 	printf ("snd: %s\n", p->send);
 	p = p->next;
@@ -146,19 +153,20 @@ setup_muxconn_struct (char **hosts,
     l = (muxconn_t *)NULL;
     c = (muxconn_t *)NULL;
 
-    while (hosts[i] != NULL) {
+    while (hosts[i] != NULL)
+    {
 	n = calloc (1, sizeof (muxconn_t));
-	if (n == NULL) {
+	if (n == NULL)
+	{
 	    strncpy (errbuf, "could not alloc memory", errbufsiz);
 	    return ((muxconn_t *) NULL);
 	}
 	n->next = (muxconn_t *) NULL;
 
-	if (c == (muxconn_t *) NULL) {
+	if (c == (muxconn_t *) NULL)
 	    c = n;
-	} else {
+	else
 	    l->next = n;
-	}
 
 	n->fd = 0;
 	strncpy (n->hostname, hosts[i], sizeof (n->hostname));
@@ -169,14 +177,19 @@ setup_muxconn_struct (char **hosts,
 	n->next = (muxconn_t *) NULL;
 	n->port = port;
 
-	if (hosts[i][0] >= '0' && hosts[i][0] <= '9') {
-	    if (inet_aton (hosts[i], &n->saddr.sin_addr) == 0) {
+	if (hosts[i][0] >= '0' && hosts[i][0] <= '9')
+	{
+	    if (inet_aton (hosts[i], &n->saddr.sin_addr) == 0)
+	    {
 		snprintf (errbuf, errbufsiz,
 			"invalid IP address supplied, %s", hosts[i]);
 		return ((muxconn_t *) NULL);
 	    }
-	} else {
-	    if ((hent = gethostbyname (hosts[i])) == NULL) {
+	}
+	else
+	{
+	    if ((hent = gethostbyname (hosts[i])) == NULL)
+	    {
 		snprintf (errbuf, errbufsiz,
 			"could not resolve host %s", hosts[i]);
 		return ((muxconn_t *) NULL);
@@ -188,7 +201,8 @@ setup_muxconn_struct (char **hosts,
 	i++;
     }
 
-    if (i == ind) {
+    if (i == ind)
+    {
 	snprintf (errbuf, errbufsiz, "no hosts supplied");
 	return ((muxconn_t *) NULL);
     }
